@@ -37,6 +37,10 @@ mvrandn <- function(lower, upper, mean, locs = NULL,
     lower <- lower / margin_sd
     sigma <- t(t(sigma / margin_sd) / margin_sd)
   }
+  if (n <= m) {
+    stop("Invalid Vecchia neighbourhood size: must be at at most the number of 
+         locations or dimension of the covariance matrix.")
+  }
   if (n > 2000) {
     stop("The package currently only support sampling TMVN/TMVT distributions
          no greater than 2000 dimensions due to fast decaying acceptance rate")
